summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql/src/encode.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql/src/encode.c')
-rw-r--r--kexi/3rdparty/kexisql/src/encode.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/3rdparty/kexisql/src/encode.c b/kexi/3rdparty/kexisql/src/encode.c
index 899901b5..3e14e641 100644
--- a/kexi/3rdparty/kexisql/src/encode.c
+++ b/kexi/3rdparty/kexisql/src/encode.c
@@ -67,7 +67,7 @@
** (2) Copy each input character into the output buffer, one by
** one, adding the offset value as you copy.
**
-** (3) If the value of an input character plus offset is 0x00, replace
+** (3) If the value of an input character plus offset is 0x00, tqreplace
** that one character by the two-character sequence 0x01 0x01.
** If the sum is 0x01, replace it with 0x01 0x02. If the sum
** is 0x27, replace it with 0x01 0x03.
@@ -101,7 +101,7 @@
*/
/*
** Encode a binary buffer "in" of size n bytes so that it contains
** no instances of characters '\'' or '\000'. The output is
** null-terminated and can be used as a string value in an INSERT
** or UPDATE statement. Use sqlite_decode_binary() to convert the
@@ -231,7 +231,7 @@ int main(int argc, char **argv){
}
for(j=0; out[j]; j++){
if( out[j]=='\'' ){
- printf(" ERROR contains (')\n");
+ printf(" ERROR tqcontains (')\n");
exit(1);
}
}
@@ -101,7 +101,7 @@
*/
/*
-** Encode a binary buffer "in" of size n bytes so that it contains
+** Encode a binary buffer "in" of size n bytes so that it tqcontains
** no instances of characters '\'' or '\000'. The output is
** null-terminated and can be used as a string value in an INSERT